@@ -1,10 +1,10 @@
 package Net::DNS::RR::DS;
 
 #
-# $Id: DS.pm 1167 2014-02-03 09:55:08Z willem $
+# $Id: DS.pm 1271 2014-10-10 21:55:38Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1167 $)[1];
+$VERSION = (qw$LastChangedRevision: 1271 $)[1];
 
 
 use strict;
@@ -19,6 +19,7 @@ Net::DNS::RR::DS - DNS DS resource record
 
 use integer;
 
+use warnings;
 use Carp;
 
 use constant BABBLE => eval { require Digest::BubbleBabble; };
@@ -235,7 +236,7 @@ sub create {
 		);
 
 	my $owner = $self->{owner}->encode();
-	my $data = pack 'a* a*', $owner, $keyrr->_canonicalRdata;
+	my $data = pack 'a* a*', $owner, $keyrr->encode_rdata;
 
 	my $arglist = $digest{$self->digtype} || croak 'unsupported digest type';
 	my ( $object, @argument ) = @$arglist;
@@ -336,6 +337,8 @@ the string method is called.
 
 =head2 create
 
+    use Net::DNS::SEC;
+
     $dsrr = create Net::DNS::RR::DS($keyrr, digtype => 'SHA-256' );
     $keyrr->print;
     $dsrr->print;
